==> mediawiki-1.23.3.tar.gz: mediawiki-1.23.3/extensions/Interwiki/Interwiki.alias.php <==
<?php
/**
 * Aliases for Special:Interwiki
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Interwiki' => array( 'Interwiki' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Interwiki' => array( 'إنترويكي' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Interwiki' => array( 'إنترويكى' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'Interwiki' => array( 'আন্তঃৱিকি' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'Interwiki' => array( 'Междууикита' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'Interwiki' => array( 'Etrewiki' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'Interwiki' => array( 'Medjuwiki' ),
);

/** Min Dong Chinese (Mìng-dĕ̤ng-ngṳ̄) */
$specialPageAliases['cdo'] = array(
	'Interwiki' => array( '跨維基' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Interwiki' => array( 'Юкъарвики' ),
);

/** Sorani Kurdish (کوردی) */
$specialPageAliases['ckb'] = array(
	'Interwiki' => array( 'نێوانویکی' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Interwiki' => array( 'Interwikitabelle', 'Interwiki-Tabelle' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Interwiki' => array( 'İnterwiki' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Interwiki' => array( 'Intervikia_ligilo' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Interwiki' => array( 'Enlaces_interligüísticos' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Interwiki' => array( 'Interviki' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Interwiki' => array( 'میان‌ویکی' ),
);

/** Franco-Provençal (arpetan) */
$specialPageAliases['frp'] = array(
	'Interwiki' => array( 'Entèrvouiqui' ),
);

/** Gagauz (Gagauz) */
$specialPageAliases['gag'] = array(
	'Interwiki' => array( 'İnterviki' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Interwiki' => array( 'Interwikis' ),
);

/** Hawaiian (Hawai`i) */
$specialPageAliases['haw'] = array(
	'Interwiki' => array( 'Waenawiki' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Interwiki' => array( 'בינוויקי' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Interwiki' => array( 'Entèwiki' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Interwiki' => array( 'Wikiközi_hivatkozások' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Interwiki' => array( 'Interwiki' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Interwiki' => array( 'インターウィキ' ),
);

/** Georgian (ქართული) */
$specialPageAliases['ka'] = array(
	'Interwiki' => array( 'ინტერვიკი' ),
);

/** Khmer (ភាសាខ្មែរ) */
$specialPageAliases['km'] = array(
	'Interwiki' => array( 'អន្តរវិគី' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Interwiki' => array( '인터위키' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Interwiki' => array( 'EngerWiki', 'Engerwiki' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'Interwiki' => array( 'Yntrawiki' ),
);

/** Latin (Latina) */
$specialPageAliases['la'] = array(
	'Interwiki' => array( 'Intervici' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'Interwiki' => array( 'Interviki' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Interwiki' => array( 'Меѓувики' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Interwiki' => array( 'അന്തർ‌വിക്കി' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'Interwiki' => array( 'आंतरविकि' ),
);

/** Punjabi (ਪੰਜਾਬੀ) */
$specialPageAliases['pa'] = array(
	'Interwiki' => array( 'ਇੰਟਰਵਿਕੀ' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'Interwiki' => array( 'Interwikis' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Interwiki' => array( 'Интервики' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'Interwiki' => array( 'आंन्तरविकि' ),
);

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = array(
	'Interwiki' => array( 'Viungovyawiki' ),
);

/** Telugu (తెలుగు) */
$specialPageAliases['te'] = array(
	'Interwiki' => array( 'అంతర్వికీ' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Interwiki' => array( 'Kawing-wiki' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Interwiki' => array( 'İnterviki' ),
);

/** Tatar (Cyrillic script) (татарча) */
$specialPageAliases['tt-cyrl'] = array(
	'Interwiki' => array( 'Интервики' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'Interwiki' => array( 'Інтервікі' ),
);

/** Urdu (اردو) */
$specialPageAliases['ur'] = array(
	'Interwiki' => array( 'بین_الویکی' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Interwiki' => array( 'Liên_wiki' ),
);

/** Yiddish (ייִדיש) */
$specialPageAliases['yi'] = array(
	'Interwiki' => array( 'אינטערוויקי' ),
);

/** Cantonese (粵語) */
$specialPageAliases['yue'] = array(
	'Interwiki' => array( '其他維基連接' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Interwiki' => array( '跨wiki', '跨维基' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Interwiki' => array( '跨wiki', '跨維基' ),
);

==> mediawiki-1.25.2.tar.gz: mediawiki-1.25.2/extensions/Interwiki/Interwiki.alias.php <==
<?php
/**
 * Aliases for Special:Interwiki
 *
 * @file
 * @ingroup Extensions
 */
// @codingStandardsIgnoreFile

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Interwiki' => array( 'Interwiki' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Interwiki' => array( 'إنترويكي' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Interwiki' => array( 'إنترويكى' ),
);

/** Assamese (অসমীয়া) */
$specialPageAliases['as'] = array(
	'Interwiki' => array( 'আন্তঃৱিকি' ),
);

/** Avaric (авар) */
$specialPageAliases['av'] = array(
	'Interwiki' => array( 'Интервики' ),
);

/** Bulgarian (български) */
$specialPageAliases['bg'] = array(
	'Interwiki' => array( 'Междууикита' ),
);

/** Western Balochi (بلوچی رخشانی) */
$specialPageAliases['bgn'] = array(
	'Interwiki' => array( 'مانجین_ویکی' ),
);

/** Breton (brezhoneg) */
$specialPageAliases['br'] = array(
	'Interwiki' => array( 'Etrewiki' ),
);

/** Bosnian (bosanski) */
$specialPageAliases['bs'] = array(
	'Interwiki' => array( 'Medjuwiki' ),
);

/** Min Dong Chinese (Mìng-dĕ̤ng-ngṳ̄) */
$specialPageAliases['cdo'] = array(
	'Interwiki' => array( '跨維基' ),
);

/** Chechen (нохчийн) */
$specialPageAliases['ce'] = array(
	'Interwiki' => array( 'Юкъарвики' ),
);

/** Sorani Kurdish (کوردی) */
$specialPageAliases['ckb'] = array(
	'Interwiki' => array( 'نێوانویکی' ),
);

/** German (Deutsch) */
$specialPageAliases['de'] = array(
	'Interwiki' => array( 'Interwikitabelle', 'Interwiki-Tabelle' ),
);

/** Zazaki (Zazaki) */
$specialPageAliases['diq'] = array(
	'Interwiki' => array( 'İnterwiki' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Interwiki' => array( 'Intervikia_ligilo' ),
);

/** Spanish (español) */
$specialPageAliases['es'] = array(
	'Interwiki' => array( 'Enlaces_interligüísticos' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Interwiki' => array( 'Interviki' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Interwiki' => array( 'میان‌ویکی' ),
);

/** Franco-Provençal (arpetan) */
$specialPageAliases['frp'] = array(
	'Interwiki' => array( 'Entèrvouiqui' ),
);

/** Gagauz (Gagauz) */
$specialPageAliases['gag'] = array(
	'Interwiki' => array( 'İnterviki' ),
);

/** Galician (galego) */
$specialPageAliases['gl'] = array(
	'Interwiki' => array( 'Interwikis' ),
);

/** Hawaiian (Hawai`i) */
$specialPageAliases['haw'] = array(
	'Interwiki' => array( 'Waenawiki' ),
);

/** Hebrew (עברית) */
$specialPageAliases['he'] = array(
	'Interwiki' => array( 'בינוויקי' ),
);

/** Haitian (Kreyòl ayisyen) */
$specialPageAliases['ht'] = array(
	'Interwiki' => array( 'Entèwiki' ),
);

/** Hungarian (magyar) */
$specialPageAliases['hu'] = array(
	'Interwiki' => array( 'Wikiközi_hivatkozások' ),
);

/** Indonesian (Bahasa Indonesia) */
$specialPageAliases['id'] = array(
	'Interwiki' => array( 'Interwiki' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Interwiki' => array( 'インターウィキ' ),
);

/** Georgian (ქართული) */
$specialPageAliases['ka'] = array(
	'Interwiki' => array( 'ინტერვიკი' ),
);

/** Khmer (ភាសាខ្មែរ) */
$specialPageAliases['km'] = array(
	'Interwiki' => array( 'អន្តរវិគី' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Interwiki' => array( '인터위키' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Interwiki' => array( 'EngerWiki', 'Engerwiki' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'Interwiki' => array( 'Yntrawiki' ),
);

/** Latin (Latina) */
$specialPageAliases['la'] = array(
	'Interwiki' => array( 'Intervici' ),
);

/** Ladino (Ladino) */
$specialPageAliases['lad'] = array(
	'Interwiki' => array( 'Interviki' ),
);

/** لوری (لوری) */
$specialPageAliases['lrc'] = array(
	'Interwiki' => array( 'مینجا_ویکی' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Interwiki' => array( 'Меѓувики' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Interwiki' => array( 'അന്തർ‌വിക്കി' ),
);

/** Marathi (मराठी) */
$specialPageAliases['mr'] = array(
	'Interwiki' => array( 'आंतरविकि' ),
);

/** Punjabi (ਪੰਜਾਬੀ) */
$specialPageAliases['pa'] = array(
	'Interwiki' => array( 'ਇੰਟਰਵਿਕੀ' ),
);

/** Portuguese (português) */
$specialPageAliases['pt'] = array(
	'Interwiki' => array( 'Interwikis' ),
);

/** Russian (русский) */
$specialPageAliases['ru'] = array(
	'Interwiki' => array( 'Интервики' ),
);

/** Sanskrit (संस्कृतम्) */
$specialPageAliases['sa'] = array(
	'Interwiki' => array( 'आंन्तरविकि' ),
);

/** Swahili (Kiswahili) */
$specialPageAliases['sw'] = array(
	'Interwiki' => array( 'Viungovyawiki' ),
);

/** Telugu (తెలుగు) */
$specialPageAliases['te'] = array(
	'Interwiki' => array( 'అంతర్వికీ' ),
);

/** Tagalog (Tagalog) */
$specialPageAliases['tl'] = array(
	'Interwiki' => array( 'Kawing-wiki' ),
);

/** Turkish (Türkçe) */
$specialPageAliases['tr'] = array(
	'Interwiki' => array( 'İnterviki' ),
);

/** Tatar (Cyrillic script) (татарча) */
$specialPageAliases['tt-cyrl'] = array(
	'Interwiki' => array( 'Интервики' ),
);

/** Ukrainian (українська) */
$specialPageAliases['uk'] = array(
	'Interwiki' => array( 'Інтервікі' ),
);

/** Urdu (اردو) */
$specialPageAliases['ur'] = array(
	'Interwiki' => array( 'بین_الویکی' ),
);

/** Vietnamese (Tiếng Việt) */
$specialPageAliases['vi'] = array(
	'Interwiki' => array( 'Liên_wiki' ),
);

/** Yiddish (ייִדיש) */
$specialPageAliases['yi'] = array(
	'Interwiki' => array( 'אינטערוויקי' ),
);

/** Cantonese (粵語) */
$specialPageAliases['yue'] = array(
	'Interwiki' => array( '其他維基連接' ),
);

/** Simplified Chinese (中文（简体）‎) */
$specialPageAliases['zh-hans'] = array(
	'Interwiki' => array( '跨wiki', '跨维基' ),
);

/** Traditional Chinese (中文（繁體）‎) */
$specialPageAliases['zh-hant'] = array(
	'Interwiki' => array( '跨Wiki', '跨維基' ),
);
